@@ -9,7 +9,7 @@
 #include <tdemessagebox.h>
 #include <tqpixmap.h>
 #include <tqstring.h>
-#include <tqdstream.h>
+#include <tqdatastream.h>
 #include <tqkeycode.h>
 #include <tqtimer.h>
 #include <tqfileinfo.h>
